const canvas = document.getElementById('network-canvas');
const ctx = canvas.getContext('2d');

const places = [
  { id: 'New York', parent: null, x: 400, y: 50 },
  { id: 'California', parent: 'USA', x: 200, y: 150 },
  {
    id: 'Los Angeles',
    parent: 'California',
    x: 100,
    y: 250,
  },
  {
    id: 'San Francisco',
    parent: 'California',
    x: 300,
    y: 250,
  },
  { id: 'Texas', parent: 'USA', x: 600, y: 150 },
  { id: 'Houston', parent: 'Texas', x: 500, y: 250 },
  { id: 'Austin', parent: 'Texas', x: 700, y: 250 },
  { id: 'Florida', parent: 'USA', x: 400, y: 150 },
  { id: 'Miami', parent: 'Florida', x: 300, y: 350 },
  { id: 'Orlando', parent: 'Florida', x: 500, y: 350 },
];

function drawNodes() {
  places.forEach((place) => {
    const radius = 20;

    ctx.beginPath();
    ctx.arc(place.x, place.y, radius, 0, Math.PI * 2);
    ctx.closePath();
    ctx.fillStyle = '#FFA500'; // Orange
    ctx.fill();

    // Node label
    ctx.fillStyle = 'black';
    ctx.font = '14px Arial';
    ctx.textAlign = 'center';
    ctx.textBaseline = 'middle';
    ctx.fillText(place.id, place.x, place.y);
  });
}

function drawLinks() {
  places.forEach((place) => {
    const parentPlace = places.find(
      (p) => p.id === place.parent,
    );

    if (parentPlace) {
      ctx.beginPath();
      ctx.moveTo(place.x, place.y);
      ctx.lineTo(parentPlace.x, parentPlace.y);
      ctx.strokeStyle = '#4169E1'; // RoyalBlue
      ctx.lineWidth = 2;
      ctx.stroke();
    }
  });
}

function drawGraph() {
  drawLinks();
  drawNodes();
}

function adjustCanvasSize() {
  let maxX = 0;
  let maxY = 0;

  places.forEach((place) => {
    if (place.x > maxX) maxX = place.x;
    if (place.y > maxY) maxY = place.y;
  });

  canvas.width = maxX + 50;
  canvas.height = maxY + 50;
}

adjustCanvasSize();
drawGraph();
